@@ -147,7 +147,7 @@ def participants_chooser(probs, choosers, spec, trace_label):
         indicating that the participant has been chosen to participate in the tour
     trace_label : str
 
-    Returns - same as logit.make_choices
+    Returns
     -------
     choices, rands
         choices, rands as returned by logit.make_choices (in same order as probs)
