@@ -1,27 +1,23 @@
 # ActivitySim
 # See full license in LICENSE.txt.
 
+import logging
 import os
 import shutil
 
-import logging
-
+import pandas as pd
 import yaml
 
-import pandas as pd
-
-from activitysim.core import config
-from activitysim.core import simulate
-
-from activitysim.core.util import reindex
 from activitysim.abm.models.util import canonical_ids as cid
+from activitysim.core import config, simulate
+from activitysim.core.util import reindex
 
-logger = logging.getLogger('estimation')
+logger = logging.getLogger("estimation")
 
-ESTIMATION_SETTINGS_FILE_NAME = 'estimation.yaml'
+ESTIMATION_SETTINGS_FILE_NAME = "estimation.yaml"
 
 
-def unlink_files(directory_path, file_types=('csv', 'yaml')):
+def unlink_files(directory_path, file_types=("csv", "yaml")):
     for file_name in os.listdir(directory_path):
         if file_name.endswith(file_types):
             file_path = os.path.join(directory_path, file_name)
@@ -34,7 +30,6 @@ def unlink_files(directory_path, file_types=('csv', 'yaml')):
 
 
 class Estimator(object):
-
     def __init__(self, bundle_name, model_name, estimation_table_recipes):
 
         logger.info("Initialize Estimator for'%s'" % (model_name,))
@@ -51,19 +46,27 @@ class Estimator(object):
             os.makedirs(output_dir)  # make directory if needed
 
         # delete estimation files
-        unlink_files(self.output_directory(), file_types=('csv', 'yaml'))
+        unlink_files(self.output_directory(), file_types=("csv", "yaml"))
         if self.bundle_name != self.model_name:
             # kind of inelegant to always delete these, but ok as they are redundantly recreated for each sub model
-            unlink_files(self.output_directory(bundle_directory=True), file_types=('csv', 'yaml'))
+            unlink_files(
+                self.output_directory(bundle_directory=True), file_types=("csv", "yaml")
+            )
 
         # FIXME - not required?
         # assert 'override_choices' in self.model_settings, \
         #     "override_choices not found for %s in %s." % (model_name, ESTIMATION_SETTINGS_FILE_NAME)
 
-        self.omnibus_tables = self.estimation_table_recipes['omnibus_tables']
-        self.omnibus_tables_append_columns = self.estimation_table_recipes['omnibus_tables_append_columns']
+        self.omnibus_tables = self.estimation_table_recipes["omnibus_tables"]
+        self.omnibus_tables_append_columns = self.estimation_table_recipes[
+            "omnibus_tables_append_columns"
+        ]
         self.tables = {}
-        self.tables_to_cache = [table_name for tables in self.omnibus_tables.values() for table_name in tables]
+        self.tables_to_cache = [
+            table_name
+            for tables in self.omnibus_tables.values()
+            for table_name in tables
+        ]
         self.alt_id_column_name = None
         self.chooser_id_column_name = None
 
@@ -121,7 +124,9 @@ class Estimator(object):
         assert self.estimating
         assert self.model_name is not None
 
-        dir = os.path.join(config.output_file_path('estimation_data_bundle'), self.bundle_name)
+        dir = os.path.join(
+            config.output_file_path("estimation_data_bundle"), self.bundle_name
+        )
 
         if bundle_directory:
             # shouldn't be asking - probably confused
@@ -152,7 +157,9 @@ class Estimator(object):
 
         return os.path.join(output_dir, file_name)
 
-    def write_table(self, df, table_name, index=True, append=True, bundle_directory=False):
+    def write_table(
+        self, df, table_name, index=True, append=True, bundle_directory=False
+    ):
         """
 
         Parameters
@@ -168,22 +175,29 @@ class Estimator(object):
 
         def cache_table(df, table_name, append):
             if table_name in self.tables and not append:
-                raise RuntimeError("cache_table %s append=False and table exists" % (table_name,))
+                raise RuntimeError(
+                    "cache_table %s append=False and table exists" % (table_name,)
+                )
             if table_name in self.tables:
                 self.tables[table_name] = pd.concat([self.tables[table_name], df])
             else:
                 self.tables[table_name] = df.copy()
 
         def write_table(df, table_name, index, append, bundle_directory):
-            if table_name.endswith('.csv'):
+            if table_name.endswith(".csv"):
                 # pass through filename without adding model or bundle name prefix
-                file_path = os.path.join(self.output_directory(bundle_directory), table_name)
+                file_path = os.path.join(
+                    self.output_directory(bundle_directory), table_name
+                )
             else:
-                file_path = self.output_file_path(table_name, 'csv', bundle_directory)
+                file_path = self.output_file_path(table_name, "csv", bundle_directory)
             file_exists = os.path.isfile(file_path)
             if file_exists and not append:
-                raise RuntimeError("write_table %s append=False and file exists: %s" % (table_name, file_path))
-            df.to_csv(file_path, mode='a', index=index, header=(not file_exists))
+                raise RuntimeError(
+                    "write_table %s append=False and file exists: %s"
+                    % (table_name, file_path)
+                )
+            df.to_csv(file_path, mode="a", index=index, header=(not file_exists))
 
         assert self.estimating
 
@@ -193,11 +207,11 @@ class Estimator(object):
 
         if cache:
             cache_table(df, table_name, append)
-            self.debug('write_table cache: %s' % table_name)
+            self.debug("write_table cache: %s" % table_name)
 
         if write:
             write_table(df, table_name, index, append, bundle_directory)
-            self.debug('write_table write: %s' % table_name)
+            self.debug("write_table write: %s" % table_name)
 
     def write_omnibus_table(self):
 
@@ -206,41 +220,50 @@ class Estimator(object):
 
         for omnibus_table, table_names in self.omnibus_tables.items():
 
-            self.debug("write_omnibus_table: %s table_names: %s" % (omnibus_table, table_names))
+            self.debug(
+                "write_omnibus_table: %s table_names: %s" % (omnibus_table, table_names)
+            )
             for t in table_names:
                 if t not in self.tables:
-                    self.warning("write_omnibus_table: %s table '%s' not found" % (omnibus_table, t))
+                    self.warning(
+                        "write_omnibus_table: %s table '%s' not found"
+                        % (omnibus_table, t)
+                    )
 
             # ignore any tables not in cache
             table_names = [t for t in table_names if t in self.tables]
-            concat_axis = 1 if omnibus_table in self.omnibus_tables_append_columns else 0
+            concat_axis = (
+                1 if omnibus_table in self.omnibus_tables_append_columns else 0
+            )
 
             df = pd.concat([self.tables[t] for t in table_names], axis=concat_axis)
-            df.sort_index(ascending=True, inplace=True, kind='mergesort')
+            df.sort_index(ascending=True, inplace=True, kind="mergesort")
 
-            file_path = self.output_file_path(omnibus_table, 'csv')
+            file_path = self.output_file_path(omnibus_table, "csv")
             assert not os.path.isfile(file_path)
 
-            df.to_csv(file_path, mode='a', index=True, header=True)
+            df.to_csv(file_path, mode="a", index=True, header=True)
 
-            self.debug('write_omnibus_choosers: %s' % file_path)
+            self.debug("write_omnibus_choosers: %s" % file_path)
 
     def write_dict(self, d, dict_name, bundle_directory):
 
         assert self.estimating
 
-        file_path = self.output_file_path(dict_name, 'yaml', bundle_directory)
+        file_path = self.output_file_path(dict_name, "yaml", bundle_directory)
 
         # we don't know how to concat, and afraid to overwrite
         assert not os.path.isfile(file_path)
 
-        with open(file_path, 'w') as f:
+        with open(file_path, "w") as f:
             # write ordered dict as array
             yaml.dump(d, f)
 
         self.debug("estimate.write_dict: %s" % file_path)
 
-    def write_coefficients(self, coefficients_df=None, model_settings=None, file_name=None):
+    def write_coefficients(
+        self, coefficients_df=None, model_settings=None, file_name=None
+    ):
         """
         Because the whole point of estimation is to generate new coefficient values
         we want to make it easy to put the coefficients file back in configs
@@ -249,7 +272,7 @@ class Estimator(object):
 
         if model_settings is not None:
             assert file_name is None
-            file_name = model_settings['COEFFICIENTS']
+            file_name = model_settings["COEFFICIENTS"]
 
         assert file_name is not None
 
@@ -266,60 +289,76 @@ class Estimator(object):
         assert self.estimating
 
         coefficients_df = simulate.read_model_coefficient_template(model_settings)
-        tag = 'coefficients_template'
+        tag = "coefficients_template"
         self.write_table(coefficients_df, tag, append=False)
 
     def write_choosers(self, choosers_df):
-        self.write_table(choosers_df, 'choosers', append=True)
+        self.write_table(choosers_df, "choosers", append=True)
 
     def write_choices(self, choices):
         if isinstance(choices, pd.Series):
-            choices = choices.to_frame(name='model_choice')
-        assert(list(choices.columns) == ['model_choice'])
-        self.write_table(choices, 'choices', append=True)
+            choices = choices.to_frame(name="model_choice")
+        assert list(choices.columns) == ["model_choice"]
+        self.write_table(choices, "choices", append=True)
 
     def write_override_choices(self, choices):
         if isinstance(choices, pd.Series):
-            choices = choices.to_frame(name='override_choice')
-        assert(list(choices.columns) == ['override_choice'])
-        self.write_table(choices, 'override_choices', append=True)
+            choices = choices.to_frame(name="override_choice")
+        assert list(choices.columns) == ["override_choice"]
+        self.write_table(choices, "override_choices", append=True)
 
     def write_constants(self, constants):
-        self.write_dict(self, constants, 'model_constants')
+        self.write_dict(self, constants, "model_constants")
 
     def write_nest_spec(self, nest_spec):
-        self.write_dict(self, nest_spec, 'nest_spec')
+        self.write_dict(self, nest_spec, "nest_spec")
 
-    def copy_model_settings(self, settings_file_name, tag='model_settings', bundle_directory=False):
+    def copy_model_settings(
+        self, settings_file_name, tag="model_settings", bundle_directory=False
+    ):
 
         input_path = config.base_settings_file_path(settings_file_name)
 
-        output_path = self.output_file_path(tag, 'yaml', bundle_directory)
+        output_path = self.output_file_path(tag, "yaml", bundle_directory)
 
         shutil.copy(input_path, output_path)
 
-    def write_model_settings(self, model_settings, settings_file_name, bundle_directory=False):
+    def write_model_settings(
+        self, model_settings, settings_file_name, bundle_directory=False
+    ):
 
-        if 'include_settings' in model_settings:
-            file_path = self.output_file_path('model_settings', 'yaml', bundle_directory)
+        if "include_settings" in model_settings:
+            file_path = self.output_file_path(
+                "model_settings", "yaml", bundle_directory
+            )
             assert not os.path.isfile(file_path)
-            with open(file_path, 'w') as f:
+            with open(file_path, "w") as f:
                 yaml.dump(model_settings, f)
         else:
-            self.copy_model_settings(settings_file_name, bundle_directory=bundle_directory)
-        if 'inherit_settings' in model_settings:
-            self.write_dict(model_settings, 'inherited_model_settings', bundle_directory)
+            self.copy_model_settings(
+                settings_file_name, bundle_directory=bundle_directory
+            )
+        if "inherit_settings" in model_settings:
+            self.write_dict(
+                model_settings, "inherited_model_settings", bundle_directory
+            )
 
     def melt_alternatives(self, df):
 
         alt_id_name = self.alt_id_column_name
 
-        assert alt_id_name is not None, \
-            "alt_id not set. Did you forget to call set_alt_id()? (%s)" % self.model_name
-        assert alt_id_name in df, \
-            "alt_id_column_name '%s' not in alternatives table (%s)" % (alt_id_name, self.model_name)
+        assert alt_id_name is not None, (
+            "alt_id not set. Did you forget to call set_alt_id()? (%s)"
+            % self.model_name
+        )
+        assert (
+            alt_id_name in df
+        ), "alt_id_column_name '%s' not in alternatives table (%s)" % (
+            alt_id_name,
+            self.model_name,
+        )
 
-        variable_column = 'variable'
+        variable_column = "variable"
 
         #            alt_dest  util_dist_0_1  util_dist_1_2  ...
         # person_id                                          ...
@@ -337,16 +376,20 @@ class Estimator(object):
             assert chooser_name in df
 
         # mergesort is the only stable sort, and we want the expressions to appear in original df column order
-        melt_df = pd.melt(df, id_vars=[chooser_name, alt_id_name]) \
-            .sort_values(by=chooser_name, kind='mergesort') \
-            .rename(columns={'variable': variable_column})
+        melt_df = (
+            pd.melt(df, id_vars=[chooser_name, alt_id_name])
+            .sort_values(by=chooser_name, kind="mergesort")
+            .rename(columns={"variable": variable_column})
+        )
 
         # person_id,alt_dest,expression,value
         # 31153,1,util_dist_0_1,1.0
         # 31153,2,util_dist_0_1,1.0
         # 31153,3,util_dist_0_1,1.0
 
-        melt_df = melt_df.set_index([chooser_name, variable_column, alt_id_name]).unstack(2)
+        melt_df = melt_df.set_index(
+            [chooser_name, variable_column, alt_id_name]
+        ).unstack(2)
         melt_df.columns = melt_df.columns.droplevel(0)
         melt_df = melt_df.reset_index(1)
 
@@ -359,21 +402,30 @@ class Estimator(object):
 
     def write_interaction_expression_values(self, df):
         df = self.melt_alternatives(df)
-        self.write_table(df, 'interaction_expression_values', append=True)
+        self.write_table(df, "interaction_expression_values", append=True)
 
     def write_expression_values(self, df):
-        self.write_table(df, 'expression_values', append=True)
+        self.write_table(df, "expression_values", append=True)
 
     def write_alternatives(self, alternatives_df, bundle_directory=False):
-        self.write_table(alternatives_df, 'alternatives', append=True, bundle_directory=bundle_directory)
+        self.write_table(
+            alternatives_df,
+            "alternatives",
+            append=True,
+            bundle_directory=bundle_directory,
+        )
 
     def write_interaction_sample_alternatives(self, alternatives_df):
         alternatives_df = self.melt_alternatives(alternatives_df)
-        self.write_table(alternatives_df, 'interaction_sample_alternatives', append=True)
+        self.write_table(
+            alternatives_df, "interaction_sample_alternatives", append=True
+        )
 
     def write_interaction_simulate_alternatives(self, interaction_df):
         interaction_df = self.melt_alternatives(interaction_df)
-        self.write_table(interaction_df, 'interaction_simulate_alternatives', append=True)
+        self.write_table(
+            interaction_df, "interaction_simulate_alternatives", append=True
+        )
 
     def get_survey_values(self, model_values, table_name, column_names):
         # convenience method so deep callers don't need to import estimation
@@ -385,7 +437,9 @@ class Estimator(object):
         assert self.estimating
         return manager.get_survey_table(table_name)
 
-    def write_spec(self, model_settings=None, file_name=None, tag='SPEC', bundle_directory=False):
+    def write_spec(
+        self, model_settings=None, file_name=None, tag="SPEC", bundle_directory=False
+    ):
 
         if model_settings is not None:
             assert file_name is None
@@ -394,13 +448,12 @@ class Estimator(object):
         input_path = config.config_file_path(file_name)
 
         table_name = tag  # more readable than full spec file_name
-        output_path = self.output_file_path(table_name, 'csv', bundle_directory)
+        output_path = self.output_file_path(table_name, "csv", bundle_directory)
         shutil.copy(input_path, output_path)
         self.debug("estimate.write_spec: %s" % output_path)
 
 
 class EstimationManager(object):
-
     def __init__(self):
 
         self.settings_initialized = False
@@ -417,30 +470,40 @@ class EstimationManager(object):
 
         assert not self.settings_initialized
         settings = config.read_model_settings(ESTIMATION_SETTINGS_FILE_NAME)
-        self.enabled = settings.get('enable', 'True')
-        self.bundles = settings.get('bundles', [])
+        self.enabled = settings.get("enable", "True")
+        self.bundles = settings.get("bundles", [])
 
-        self.model_estimation_table_types = settings.get('model_estimation_table_types', {})
-        self.estimation_table_recipes = settings.get('estimation_table_recipes', {})
+        self.model_estimation_table_types = settings.get(
+            "model_estimation_table_types", {}
+        )
+        self.estimation_table_recipes = settings.get("estimation_table_recipes", {})
 
         if self.enabled:
 
-            self.survey_tables = settings.get('survey_tables', {})
+            self.survey_tables = settings.get("survey_tables", {})
             for table_name, table_info in self.survey_tables.items():
-                assert 'file_name' in table_info, \
-                    "No file name specified for survey_table '%s' in %s" % (table_name, ESTIMATION_SETTINGS_FILE_NAME)
-                file_path = config.data_file_path(table_info['file_name'], mandatory=True)
-                assert os.path.exists(file_path), \
-                    "File for survey table '%s' not found: %s" % (table_name, file_path)
+                assert (
+                    "file_name" in table_info
+                ), "No file name specified for survey_table '%s' in %s" % (
+                    table_name,
+                    ESTIMATION_SETTINGS_FILE_NAME,
+                )
+                file_path = config.data_file_path(
+                    table_info["file_name"], mandatory=True
+                )
+                assert os.path.exists(
+                    file_path
+                ), "File for survey table '%s' not found: %s" % (table_name, file_path)
                 df = pd.read_csv(file_path)
-                index_col = table_info.get('index_col')
+                index_col = table_info.get("index_col")
                 if index_col is not None:
-                    assert index_col in df.columns, \
-                        "Index col '%s' not in survey_table '%s' in file: %s % (index_col, table_name, file_path)"
+                    assert (
+                        index_col in df.columns
+                    ), "Index col '%s' not in survey_table '%s' in file: %s % (index_col, table_name, file_path)"
                     df.set_index(index_col, inplace=True)
 
                 # add the table df to survey_tables
-                table_info['df'] = df
+                table_info["df"] = df
 
         self.settings_initialized = True
 
@@ -467,25 +530,40 @@ class EstimationManager(object):
         bundle_name = bundle_name or model_name
 
         if bundle_name not in self.bundles:
-            logger.warning(f"estimation bundle {bundle_name} not in settings file {ESTIMATION_SETTINGS_FILE_NAME}")
+            logger.warning(
+                f"estimation bundle {bundle_name} not in settings file {ESTIMATION_SETTINGS_FILE_NAME}"
+            )
             return None
 
         # can't estimate the same model simultaneously
-        assert model_name not in self.estimating, \
-            "Cant begin estimating %s - already estimating that model." % (model_name, )
+        assert (
+            model_name not in self.estimating
+        ), "Cant begin estimating %s - already estimating that model." % (model_name,)
 
-        assert bundle_name in self.model_estimation_table_types, \
-            "No estimation_table_type for %s in %s." % (bundle_name, ESTIMATION_SETTINGS_FILE_NAME)
+        assert (
+            bundle_name in self.model_estimation_table_types
+        ), "No estimation_table_type for %s in %s." % (
+            bundle_name,
+            ESTIMATION_SETTINGS_FILE_NAME,
+        )
 
         model_estimation_table_type = self.model_estimation_table_types[bundle_name]
 
-        assert model_estimation_table_type in self.estimation_table_recipes, \
-            "model_estimation_table_type '%s' for model %s no in %s." % \
-            (model_estimation_table_type, model_name, ESTIMATION_SETTINGS_FILE_NAME)
+        assert (
+            model_estimation_table_type in self.estimation_table_recipes
+        ), "model_estimation_table_type '%s' for model %s no in %s." % (
+            model_estimation_table_type,
+            model_name,
+            ESTIMATION_SETTINGS_FILE_NAME,
+        )
 
-        self.estimating[model_name] = \
-            Estimator(bundle_name, model_name,
-                      estimation_table_recipes=self.estimation_table_recipes[model_estimation_table_type])
+        self.estimating[model_name] = Estimator(
+            bundle_name,
+            model_name,
+            estimation_table_recipes=self.estimation_table_recipes[
+                model_estimation_table_type
+            ],
+        )
 
         return self.estimating[model_name]
 
@@ -496,22 +574,31 @@ class EstimationManager(object):
     def get_survey_table(self, table_name):
         assert self.enabled
         if table_name not in self.survey_tables:
-            logger.warning("EstimationManager. get_survey_table: survey table '%s' not in survey_tables" % table_name)
-        df = self.survey_tables[table_name].get('df')
+            logger.warning(
+                "EstimationManager. get_survey_table: survey table '%s' not in survey_tables"
+                % table_name
+            )
+        df = self.survey_tables[table_name].get("df")
         return df
 
     def get_survey_values(self, model_values, table_name, column_names):
 
-        assert isinstance(model_values, (pd.Series, pd.DataFrame, pd.Index)), \
-            "get_survey_values model_values has unrecognized type %s" % type(model_values)
+        assert isinstance(
+            model_values, (pd.Series, pd.DataFrame, pd.Index)
+        ), "get_survey_values model_values has unrecognized type %s" % type(
+            model_values
+        )
 
-        dest_index = model_values if isinstance(model_values, (pd.Index)) else model_values.index
+        dest_index = (
+            model_values if isinstance(model_values, (pd.Index)) else model_values.index
+        )
 
         # read override_df table
         survey_df = manager.get_survey_table(table_name)
 
-        assert survey_df is not None, \
-            "get_survey_values: table '%s' not found" % (table_name,)
+        assert survey_df is not None, "get_survey_values: table '%s' not found" % (
+            table_name,
+        )
 
         column_name = column_names if isinstance(column_names, str) else None
         if column_name:
@@ -519,47 +606,67 @@ class EstimationManager(object):
 
         if not set(column_names).issubset(set(survey_df.columns)):
             missing_columns = list(set(column_names) - set(survey_df.columns))
-            logger.error("missing columns (%s) in survey table %s" % (missing_columns, table_name))
-            print("survey table columns: %s" % (survey_df.columns, ))
-            raise RuntimeError("missing columns (%s) in survey table %s" % (missing_columns, table_name))
+            logger.error(
+                "missing columns (%s) in survey table %s"
+                % (missing_columns, table_name)
+            )
+            print("survey table columns: %s" % (survey_df.columns,))
+            raise RuntimeError(
+                "missing columns (%s) in survey table %s"
+                % (missing_columns, table_name)
+            )
 
-        assert set(column_names).issubset(set(survey_df.columns)), \
-            f"missing columns ({list(set(column_names) - set(survey_df.columns))}) " \
+        assert set(column_names).issubset(set(survey_df.columns)), (
+            f"missing columns ({list(set(column_names) - set(survey_df.columns))}) "
             f"in survey table {table_name} {list(survey_df.columns)}"
+        )
 
         # for now tour_id is asim_tour_id in survey_df
         asim_df_index_name = dest_index.name
         if asim_df_index_name == survey_df.index.name:
             # survey table has same index as activitysim
-            survey_df_index_column = 'index'
+            survey_df_index_column = "index"
         elif asim_df_index_name in survey_df.columns:
             # survey table has activitysim index as column
             survey_df_index_column = asim_df_index_name
-        elif 'asim_%s' % asim_df_index_name in survey_df.columns:
+        elif "asim_%s" % asim_df_index_name in survey_df.columns:
             # survey table has activitysim index as column with asim_ prefix
-            survey_df_index_column = 'asim_%s' % asim_df_index_name
+            survey_df_index_column = "asim_%s" % asim_df_index_name
         else:
-            logger.error("get_survey_values:index '%s' not in survey table" % dest_index.name)
+            logger.error(
+                "get_survey_values:index '%s' not in survey table" % dest_index.name
+            )
             # raise RuntimeError("index '%s' not in survey table %s" % (dest_index.name, table_name)
             survey_df_index_column = None
 
-        logger.debug("get_survey_values: reindexing using %s.%s" % (table_name, survey_df_index_column))
+        logger.debug(
+            "get_survey_values: reindexing using %s.%s"
+            % (table_name, survey_df_index_column)
+        )
 
         values = pd.DataFrame(index=dest_index)
         for c in column_names:
-            if survey_df_index_column == 'index':
+            if survey_df_index_column == "index":
                 survey_values = survey_df[c]
             else:
-                survey_values = pd.Series(survey_df[c].values, index=survey_df[survey_df_index_column])
+                survey_values = pd.Series(
+                    survey_df[c].values, index=survey_df[survey_df_index_column]
+                )
 
             survey_values = reindex(survey_values, dest_index)
 
             # shouldn't be any choices we can't override
             missing_values = survey_values.isna()
             if missing_values.any():
-                logger.error("missing survey_values for %s\n%s" % (c, dest_index[missing_values]))
-                logger.error("couldn't get_survey_values for %s in %s\n" % (c, table_name))
-                raise RuntimeError("couldn't get_survey_values for %s in %s\n" % (c, table_name))
+                logger.error(
+                    "missing survey_values for %s\n%s" % (c, dest_index[missing_values])
+                )
+                logger.error(
+                    "couldn't get_survey_values for %s in %s\n" % (c, table_name)
+                )
+                raise RuntimeError(
+                    "couldn't get_survey_values for %s in %s\n" % (c, table_name)
+                )
 
             values[c] = survey_values
 
