@@ -2,23 +2,16 @@
 # See full license in LICENSE.txt.
 import logging
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
-from activitysim.core import tracing
-from activitysim.core import config
-from activitysim.core import los
-from activitysim.core import simulate
-from activitysim.core import inject
-from activitysim.core import pipeline
-
+from activitysim.abm.tables.size_terms import tour_destination_size_terms
+from activitysim.core import config, inject, los, pipeline, simulate, tracing
+from activitysim.core.interaction_sample import interaction_sample
+from activitysim.core.interaction_sample_simulate import interaction_sample_simulate
 from activitysim.core.util import reindex
 
-from activitysim.core.interaction_sample_simulate import interaction_sample_simulate
-from activitysim.core.interaction_sample import interaction_sample
-
 from . import logsums as logsum
-from activitysim.abm.tables.size_terms import tour_destination_size_terms
 
 logger = logging.getLogger(__name__)
 DUMP = False
@@ -34,10 +27,11 @@ class SizeTermCalculator(object):
     def __init__(self, size_term_selector):
 
         # do this once so they can request size_terms for various segments (tour_type or purpose)
-        land_use = inject.get_table('land_use')
-        size_terms = inject.get_injectable('size_terms')
-        self.destination_size_terms = \
-            tour_destination_size_terms(land_use, size_terms, size_term_selector)
+        land_use = inject.get_table("land_use")
+        size_terms = inject.get_injectable("size_terms")
+        self.destination_size_terms = tour_destination_size_terms(
+            land_use, size_terms, size_term_selector
+        )
 
         assert not self.destination_size_terms.isna().any(axis=None)
 
@@ -49,15 +43,19 @@ class SizeTermCalculator(object):
         # convenient if creating or merging with alts
 
         size_terms = self.destination_size_terms[[segment_name]].copy()
-        size_terms.columns = ['size_term']
+        size_terms.columns = ["size_term"]
 
         # FIXME - no point in considering impossible alternatives (where dest size term is zero)
-        logger.debug(f"SizeTermCalculator dropping {(~(size_terms.size_term > 0)).sum()} "
-                     f"of {len(size_terms)} rows where size_term is zero for {segment_name}")
+        logger.debug(
+            f"SizeTermCalculator dropping {(~(size_terms.size_term > 0)).sum()} "
+            f"of {len(size_terms)} rows where size_term is zero for {segment_name}"
+        )
         size_terms = size_terms[size_terms.size_term > 0]
 
         if len(size_terms) == 0:
-            logger.warning(f"SizeTermCalculator: no zones with non-zero size terms for {segment_name} in {trace_label}")
+            logger.warning(
+                f"SizeTermCalculator: no zones with non-zero size terms for {segment_name} in {trace_label}"
+            )
 
         return size_terms
 
@@ -68,36 +66,44 @@ class SizeTermCalculator(object):
 
 
 def _destination_sample(
-        spec_segment_name,
-        choosers,
-        destination_size_terms,
-        skims,
-        estimator,
-        model_settings,
-        alt_dest_col_name,
-        chunk_size,
-        chunk_tag,
-        trace_label):
+    spec_segment_name,
+    choosers,
+    destination_size_terms,
+    skims,
+    estimator,
+    model_settings,
+    alt_dest_col_name,
+    chunk_size,
+    chunk_tag,
+    trace_label,
+):
 
-    model_spec = simulate.spec_for_segment(model_settings, spec_id='SAMPLE_SPEC',
-                                           segment_name=spec_segment_name, estimator=estimator)
+    model_spec = simulate.spec_for_segment(
+        model_settings,
+        spec_id="SAMPLE_SPEC",
+        segment_name=spec_segment_name,
+        estimator=estimator,
+    )
 
     logger.info("running %s with %d tours", trace_label, len(choosers))
 
-    sample_size = model_settings['SAMPLE_SIZE']
-    if config.setting('disable_destination_sampling', False) or (estimator and estimator.want_unsampled_alternatives):
+    sample_size = model_settings["SAMPLE_SIZE"]
+    if config.setting("disable_destination_sampling", False) or (
+        estimator and estimator.want_unsampled_alternatives
+    ):
         # FIXME interaction_sample will return unsampled complete alternatives with probs and pick_count
-        logger.info("Estimation mode for %s using unsampled alternatives short_circuit_choices" % (trace_label,))
+        logger.info(
+            "Estimation mode for %s using unsampled alternatives short_circuit_choices"
+            % (trace_label,)
+        )
         sample_size = 0
 
-    locals_d = {
-        'skims': skims
-    }
+    locals_d = {"skims": skims}
     constants = config.get_model_constants(model_settings)
     if constants is not None:
         locals_d.update(constants)
 
-    log_alt_losers = config.setting('log_alt_losers', False)
+    log_alt_losers = config.setting("log_alt_losers", False)
 
     choices = interaction_sample(
         choosers,
@@ -110,39 +116,42 @@ def _destination_sample(
         locals_d=locals_d,
         chunk_size=chunk_size,
         chunk_tag=chunk_tag,
-        trace_label=trace_label)
+        trace_label=trace_label,
+    )
 
     # remember person_id in chosen alts so we can merge with persons in subsequent steps
     # (broadcasts person_id onto all alternatives sharing the same tour_id index value)
-    choices['person_id'] = choosers.person_id
+    choices["person_id"] = choosers.person_id
 
     return choices
 
 
 def destination_sample(
-        spec_segment_name,
-        choosers,
-        model_settings,
-        network_los,
-        destination_size_terms,
-        estimator,
-        chunk_size, trace_label):
+    spec_segment_name,
+    choosers,
+    model_settings,
+    network_los,
+    destination_size_terms,
+    estimator,
+    chunk_size,
+    trace_label,
+):
 
-    chunk_tag = 'tour_destination.sample'
+    chunk_tag = "tour_destination.sample"
 
     # create wrapper with keys for this lookup
     # the skims will be available under the name "skims" for any @ expressions
-    skim_origin_col_name = model_settings['CHOOSER_ORIG_COL_NAME']
+    skim_origin_col_name = model_settings["CHOOSER_ORIG_COL_NAME"]
     skim_dest_col_name = destination_size_terms.index.name
     # (logit.interaction_dataset suffixes duplicate chooser column with '_chooser')
-    if (skim_origin_col_name == skim_dest_col_name):
-        skim_origin_col_name = f'{skim_origin_col_name}_chooser'
+    if skim_origin_col_name == skim_dest_col_name:
+        skim_origin_col_name = f"{skim_origin_col_name}_chooser"
 
     skim_dict = network_los.get_default_skim_dict()
     skims = skim_dict.wrap(skim_origin_col_name, skim_dest_col_name)
 
     # the name of the dest column to be returned in choices
-    alt_dest_col_name = model_settings['ALT_DEST_COL_NAME']
+    alt_dest_col_name = model_settings["ALT_DEST_COL_NAME"]
 
     choices = _destination_sample(
         spec_segment_name,
@@ -152,20 +161,22 @@ def destination_sample(
         estimator,
         model_settings,
         alt_dest_col_name,
-        chunk_size, chunk_tag=chunk_tag,
-        trace_label=trace_label)
+        chunk_size,
+        chunk_tag=chunk_tag,
+        trace_label=trace_label,
+    )
 
     return choices
 
 
 # temp column names for presampling
-DEST_MAZ = 'dest_MAZ'
-DEST_TAZ = 'dest_TAZ'
-ORIG_TAZ = 'TAZ'  # likewise a temp, but if already in choosers, we assume we can use it opportunistically
+DEST_MAZ = "dest_MAZ"
+DEST_TAZ = "dest_TAZ"
+ORIG_TAZ = "TAZ"  # likewise a temp, but if already in choosers, we assume we can use it opportunistically
 
 
 def map_maz_to_taz(s, network_los):
-    maz_to_taz = network_los.maz_taz_df[['MAZ', 'TAZ']].set_index('MAZ').TAZ
+    maz_to_taz = network_los.maz_taz_df[["MAZ", "TAZ"]].set_index("MAZ").TAZ
     return s.map(maz_to_taz)
 
 
@@ -180,9 +191,9 @@ def aggregate_size_terms(dest_size_terms, network_los):
     MAZ_size_terms[DEST_TAZ] = map_maz_to_taz(MAZ_size_terms.index, network_los)
 
     # aggregate to TAZ
-    TAZ_size_terms = MAZ_size_terms.groupby(DEST_TAZ).agg({'size_term': 'sum'})
+    TAZ_size_terms = MAZ_size_terms.groupby(DEST_TAZ).agg({"size_term": "sum"})
     TAZ_size_terms[DEST_TAZ] = TAZ_size_terms.index
-    assert not TAZ_size_terms['size_term'].isna().any()
+    assert not TAZ_size_terms["size_term"].isna().any()
 
     #           size_term
     # dest_TAZ
@@ -192,8 +203,10 @@ def aggregate_size_terms(dest_size_terms, network_los):
 
     # add crosswalk DEST_TAZ column to MAZ_size_terms
     # MAZ_size_terms = MAZ_size_terms.sort_values([DEST_TAZ, 'size_term'])  # maybe helpful for debugging
-    MAZ_size_terms = MAZ_size_terms[[DEST_TAZ, 'size_term']].reset_index(drop=False)
-    MAZ_size_terms = MAZ_size_terms.sort_values([DEST_TAZ, 'zone_id']).reset_index(drop=True)
+    MAZ_size_terms = MAZ_size_terms[[DEST_TAZ, "size_term"]].reset_index(drop=False)
+    MAZ_size_terms = MAZ_size_terms.sort_values([DEST_TAZ, "zone_id"]).reset_index(
+        drop=True
+    )
 
     #       zone_id  dest_TAZ  size_term
     # 0        6097         2       10.0
@@ -231,21 +244,27 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
     trace_hh_id = inject.get_injectable("trace_hh_id", None)
     have_trace_targets = trace_hh_id and tracing.has_trace_targets(taz_sample)
     if have_trace_targets:
-        trace_label = tracing.extend_trace_label(trace_label, 'choose_MAZ_for_TAZ')
+        trace_label = tracing.extend_trace_label(trace_label, "choose_MAZ_for_TAZ")
 
-        CHOOSER_ID = taz_sample.index.name  # zone_id for tours, but person_id for location choice
+        CHOOSER_ID = (
+            taz_sample.index.name
+        )  # zone_id for tours, but person_id for location choice
         assert CHOOSER_ID is not None
 
         # write taz choices, pick_counts, probs
         trace_targets = tracing.trace_targets(taz_sample)
-        tracing.trace_df(taz_sample[trace_targets],
-                         label=tracing.extend_trace_label(trace_label, 'taz_sample'),
-                         transpose=False)
+        tracing.trace_df(
+            taz_sample[trace_targets],
+            label=tracing.extend_trace_label(trace_label, "taz_sample"),
+            transpose=False,
+        )
 
     # redupe taz_sample[[DEST_TAZ, 'prob']] using pick_count to repeat rows
-    taz_choices = taz_sample[[DEST_TAZ, 'prob']].reset_index(drop=False)
-    taz_choices = taz_choices.reindex(taz_choices.index.repeat(taz_sample.pick_count)).reset_index(drop=True)
-    taz_choices = taz_choices.rename(columns={'prob': 'TAZ_prob'})
+    taz_choices = taz_sample[[DEST_TAZ, "prob"]].reset_index(drop=False)
+    taz_choices = taz_choices.reindex(
+        taz_choices.index.repeat(taz_sample.pick_count)
+    ).reset_index(drop=True)
+    taz_choices = taz_choices.rename(columns={"prob": "TAZ_prob"})
 
     # print(f"taz_choices\n{taz_choices}")
     #        tour_id  dest_TAZ  TAZ_prob
@@ -261,7 +280,9 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
     # 2       24251         2     10.904
 
     # just to make it clear we are siloing choices by chooser_id
-    chooser_id_col = taz_sample.index.name  # should be canonical chooser index name (e.g. 'person_id')
+    chooser_id_col = (
+        taz_sample.index.name
+    )  # should be canonical chooser index name (e.g. 'person_id')
 
     # for random_for_df, we need df with de-duplicated chooser canonical index
     chooser_df = pd.DataFrame(index=taz_sample.index[~taz_sample.index.duplicated()])
@@ -273,15 +294,21 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
     taz_sample_size = taz_choices.groupby(chooser_id_col)[DEST_TAZ].count().max()
 
     # taz_choices index values should be contiguous
-    assert (taz_choices[chooser_id_col] == np.repeat(chooser_df.index, taz_sample_size)).all()
+    assert (
+        taz_choices[chooser_id_col] == np.repeat(chooser_df.index, taz_sample_size)
+    ).all()
 
     # we need to choose a MAZ for each DEST_TAZ choice
     # probability of choosing MAZ based on MAZ size_term fraction of TAZ total
     # there will be a different set (and number) of candidate MAZs for each TAZ
     # (preserve index, which will have duplicates as result of join)
     # maz_sizes.index is the integer offset into taz_choices of the taz for which the maz_size row is a candidate)
-    maz_sizes = pd.merge(taz_choices[[chooser_id_col, DEST_TAZ]].reset_index(),
-                         MAZ_size_terms, how='left', on=DEST_TAZ).set_index('index')
+    maz_sizes = pd.merge(
+        taz_choices[[chooser_id_col, DEST_TAZ]].reset_index(),
+        MAZ_size_terms,
+        how="left",
+        on=DEST_TAZ,
+    ).set_index("index")
 
     #         tour_id  dest_TAZ  zone_id  size_term
     # index
@@ -296,9 +323,11 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
 
         maz_sizes_trace_targets = tracing.trace_targets(maz_sizes, slicer=CHOOSER_ID)
         trace_maz_sizes = maz_sizes[maz_sizes_trace_targets]
-        tracing.trace_df(trace_maz_sizes,
-                         label=tracing.extend_trace_label(trace_label, 'maz_sizes'),
-                         transpose=False)
+        tracing.trace_df(
+            trace_maz_sizes,
+            label=tracing.extend_trace_label(trace_label, "maz_sizes"),
+            transpose=False,
+        )
 
     # number of DEST_TAZ candidates per chooser
     maz_counts = maz_sizes.groupby(maz_sizes.index).size().values
@@ -316,7 +345,9 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
     inserts = np.repeat(last_row_offsets, max_maz_count - maz_counts)
 
     # insert zero filler to pad each alternative set to same size
-    padded_maz_sizes = np.insert(maz_sizes.size_term.values, inserts, 0.0).reshape(-1, max_maz_count)
+    padded_maz_sizes = np.insert(maz_sizes.size_term.values, inserts, 0.0).reshape(
+        -1, max_maz_count
+    )
 
     # prob array with one row TAZ_choice, one column per alternative
     row_sums = padded_maz_sizes.sum(axis=1)
@@ -336,50 +367,82 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
     # shouldn't have chosen any of the dummy pad positions
     assert (positions < maz_counts).all()
 
-    taz_choices[DEST_MAZ] = maz_sizes['zone_id'].take(positions + first_row_offsets)
-    taz_choices['MAZ_prob'] = maz_probs[np.arange(maz_probs.shape[0]), positions]
-    taz_choices['prob'] = taz_choices['TAZ_prob'] * taz_choices['MAZ_prob']
+    taz_choices[DEST_MAZ] = maz_sizes["zone_id"].take(positions + first_row_offsets)
+    taz_choices["MAZ_prob"] = maz_probs[np.arange(maz_probs.shape[0]), positions]
+    taz_choices["prob"] = taz_choices["TAZ_prob"] * taz_choices["MAZ_prob"]
 
     if have_trace_targets:
 
-        taz_choices_trace_targets = tracing.trace_targets(taz_choices, slicer=CHOOSER_ID)
+        taz_choices_trace_targets = tracing.trace_targets(
+            taz_choices, slicer=CHOOSER_ID
+        )
         trace_taz_choices_df = taz_choices[taz_choices_trace_targets]
-        tracing.trace_df(trace_taz_choices_df,
-                         label=tracing.extend_trace_label(trace_label, 'taz_choices'),
-                         transpose=False)
+        tracing.trace_df(
+            trace_taz_choices_df,
+            label=tracing.extend_trace_label(trace_label, "taz_choices"),
+            transpose=False,
+        )
 
         lhs_df = trace_taz_choices_df[[CHOOSER_ID, DEST_TAZ]]
-        alt_dest_columns = [f'dest_maz_{c}' for c in range(max_maz_count)]
+        alt_dest_columns = [f"dest_maz_{c}" for c in range(max_maz_count)]
 
         # following the same logic as the full code, but for trace cutout
         trace_maz_counts = maz_counts[taz_choices_trace_targets]
         trace_last_row_offsets = maz_counts[taz_choices_trace_targets].cumsum()
-        trace_inserts = np.repeat(trace_last_row_offsets, max_maz_count - trace_maz_counts)
+        trace_inserts = np.repeat(
+            trace_last_row_offsets, max_maz_count - trace_maz_counts
+        )
 
         # trace dest_maz_alts
-        padded_maz_sizes = np.insert(trace_maz_sizes[CHOOSER_ID].values, trace_inserts, 0.0).reshape(-1, max_maz_count)
-        df = pd.DataFrame(data=padded_maz_sizes,
-                          columns=alt_dest_columns, index=trace_taz_choices_df.index)
+        padded_maz_sizes = np.insert(
+            trace_maz_sizes[CHOOSER_ID].values, trace_inserts, 0.0
+        ).reshape(-1, max_maz_count)
+        df = pd.DataFrame(
+            data=padded_maz_sizes,
+            columns=alt_dest_columns,
+            index=trace_taz_choices_df.index,
+        )
         df = pd.concat([lhs_df, df], axis=1)
-        tracing.trace_df(df, label=tracing.extend_trace_label(trace_label, 'dest_maz_alts'), transpose=False)
+        tracing.trace_df(
+            df,
+            label=tracing.extend_trace_label(trace_label, "dest_maz_alts"),
+            transpose=False,
+        )
 
         # trace dest_maz_size_terms
-        padded_maz_sizes = np.insert(trace_maz_sizes['size_term'].values, trace_inserts, 0.0).reshape(-1, max_maz_count)
-        df = pd.DataFrame(data=padded_maz_sizes,
-                          columns=alt_dest_columns, index=trace_taz_choices_df.index)
+        padded_maz_sizes = np.insert(
+            trace_maz_sizes["size_term"].values, trace_inserts, 0.0
+        ).reshape(-1, max_maz_count)
+        df = pd.DataFrame(
+            data=padded_maz_sizes,
+            columns=alt_dest_columns,
+            index=trace_taz_choices_df.index,
+        )
         df = pd.concat([lhs_df, df], axis=1)
-        tracing.trace_df(df, label=tracing.extend_trace_label(trace_label, 'dest_maz_size_terms'), transpose=False)
+        tracing.trace_df(
+            df,
+            label=tracing.extend_trace_label(trace_label, "dest_maz_size_terms"),
+            transpose=False,
+        )
 
         # trace dest_maz_probs
-        df = pd.DataFrame(data=maz_probs[taz_choices_trace_targets],
-                          columns=alt_dest_columns, index=trace_taz_choices_df.index)
+        df = pd.DataFrame(
+            data=maz_probs[taz_choices_trace_targets],
+            columns=alt_dest_columns,
+            index=trace_taz_choices_df.index,
+        )
         df = pd.concat([lhs_df, df], axis=1)
-        df['rand'] = rands[taz_choices_trace_targets]
-        tracing.trace_df(df, label=tracing.extend_trace_label(trace_label, 'dest_maz_probs'), transpose=False)
+        df["rand"] = rands[taz_choices_trace_targets]
+        tracing.trace_df(
+            df,
+            label=tracing.extend_trace_label(trace_label, "dest_maz_probs"),
+            transpose=False,
+        )
 
-    taz_choices = taz_choices.drop(columns=['TAZ_prob', 'MAZ_prob'])
-    taz_choices = taz_choices.groupby([chooser_id_col, DEST_MAZ]).agg(prob=('prob', 'max'),
-                                                                      pick_count=('prob', 'count'))
+    taz_choices = taz_choices.drop(columns=["TAZ_prob", "MAZ_prob"])
+    taz_choices = taz_choices.groupby([chooser_id_col, DEST_MAZ]).agg(
+        prob=("prob", "max"), pick_count=("prob", "count")
+    )
 
     taz_choices.reset_index(level=DEST_MAZ, inplace=True)
 
@@ -387,25 +450,29 @@ def choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label):
 
 
 def destination_presample(
-        spec_segment_name,
-        choosers,
-        model_settings,
-        network_los,
-        destination_size_terms,
-        estimator,
-        chunk_size, trace_label):
+    spec_segment_name,
+    choosers,
+    model_settings,
+    network_los,
+    destination_size_terms,
+    estimator,
+    chunk_size,
+    trace_label,
+):
 
-    trace_label = tracing.extend_trace_label(trace_label, 'presample')
-    chunk_tag = 'tour_destination.presample'
+    trace_label = tracing.extend_trace_label(trace_label, "presample")
+    chunk_tag = "tour_destination.presample"
 
     logger.info(f"{trace_label} location_presample")
 
-    alt_dest_col_name = model_settings['ALT_DEST_COL_NAME']
+    alt_dest_col_name = model_settings["ALT_DEST_COL_NAME"]
     assert DEST_TAZ != alt_dest_col_name
 
-    MAZ_size_terms, TAZ_size_terms = aggregate_size_terms(destination_size_terms, network_los)
+    MAZ_size_terms, TAZ_size_terms = aggregate_size_terms(
+        destination_size_terms, network_los
+    )
 
-    orig_maz = model_settings['CHOOSER_ORIG_COL_NAME']
+    orig_maz = model_settings["CHOOSER_ORIG_COL_NAME"]
     assert orig_maz in choosers
     if ORIG_TAZ not in choosers:
         choosers[ORIG_TAZ] = map_maz_to_taz(choosers[orig_maz], network_los)
@@ -413,7 +480,7 @@ def destination_presample(
     # create wrapper with keys for this lookup - in this case there is a HOME_TAZ in the choosers
     # and a DEST_TAZ in the alternatives which get merged during interaction
     # the skims will be available under the name "skims" for any @ expressions
-    skim_dict = network_los.get_skim_dict('taz')
+    skim_dict = network_los.get_skim_dict("taz")
     skims = skim_dict.wrap(ORIG_TAZ, DEST_TAZ)
 
     taz_sample = _destination_sample(
@@ -424,8 +491,10 @@ def destination_presample(
         estimator,
         model_settings,
         DEST_TAZ,
-        chunk_size, chunk_tag=chunk_tag,
-        trace_label=trace_label)
+        chunk_size,
+        chunk_tag=chunk_tag,
+        trace_label=trace_label,
+    )
 
     # choose a MAZ for each DEST_TAZ choice, choice probability based on MAZ size_term fraction of TAZ total
     maz_choices = choose_MAZ_for_TAZ(taz_sample, MAZ_size_terms, trace_label)
@@ -437,36 +506,50 @@ def destination_presample(
 
 
 def run_destination_sample(
-        spec_segment_name,
-        tours,
-        persons_merged,
-        model_settings,
-        network_los,
-        destination_size_terms,
-        estimator,
-        chunk_size, trace_label):
+    spec_segment_name,
+    tours,
+    persons_merged,
+    model_settings,
+    network_los,
+    destination_size_terms,
+    estimator,
+    chunk_size,
+    trace_label,
+):
 
     # FIXME - MEMORY HACK - only include columns actually used in spec (omit them pre-merge)
-    chooser_columns = model_settings['SIMULATE_CHOOSER_COLUMNS']
-    persons_merged = persons_merged[[c for c in persons_merged.columns if c in chooser_columns]]
-    tours = tours[[c for c in tours.columns if c in chooser_columns or c == 'person_id']]
-    choosers = pd.merge(tours, persons_merged, left_on='person_id', right_index=True, how='left')
+    chooser_columns = model_settings["SIMULATE_CHOOSER_COLUMNS"]
+    persons_merged = persons_merged[
+        [c for c in persons_merged.columns if c in chooser_columns]
+    ]
+    tours = tours[
+        [c for c in tours.columns if c in chooser_columns or c == "person_id"]
+    ]
+    choosers = pd.merge(
+        tours, persons_merged, left_on="person_id", right_index=True, how="left"
+    )
 
     # interaction_sample requires that choosers.index.is_monotonic_increasing
     if not choosers.index.is_monotonic_increasing:
-        logger.debug(f"run_destination_sample {trace_label} sorting choosers because not monotonic_increasing")
+        logger.debug(
+            f"run_destination_sample {trace_label} sorting choosers because not monotonic_increasing"
+        )
         choosers = choosers.sort_index()
 
     # by default, enable presampling for multizone systems, unless they disable it in settings file
     pre_sample_taz = not (network_los.zone_system == los.ONE_ZONE)
-    if pre_sample_taz and not config.setting('want_dest_choice_presampling', True):
+    if pre_sample_taz and not config.setting("want_dest_choice_presampling", True):
         pre_sample_taz = False
-        logger.info(f"Disabled destination zone presampling for {trace_label} "
-                    f"because 'want_dest_choice_presampling' setting is False")
+        logger.info(
+            f"Disabled destination zone presampling for {trace_label} "
+            f"because 'want_dest_choice_presampling' setting is False"
+        )
 
     if pre_sample_taz:
 
-        logger.info("Running %s destination_presample with %d tours" % (trace_label, len(tours)))
+        logger.info(
+            "Running %s destination_presample with %d tours" % (trace_label, len(tours))
+        )
 
         choices = destination_presample(
             spec_segment_name,
@@ -475,7 +558,9 @@ def run_destination_sample(
             network_los,
             destination_size_terms,
             estimator,
-            chunk_size, trace_label)
+            chunk_size,
+            trace_label,
+        )
 
     else:
         choices = destination_sample(
@@ -485,23 +570,26 @@ def run_destination_sample(
             network_los,
             destination_size_terms,
             estimator,
-            chunk_size, trace_label)
+            chunk_size,
+            trace_label,
+        )
 
     # remember person_id in chosen alts so we can merge with persons in subsequent steps
     # (broadcasts person_id onto all alternatives sharing the same tour_id index value)
-    choices['person_id'] = tours.person_id
+    choices["person_id"] = tours.person_id
 
     return choices
 
 
 def run_destination_logsums(
-        tour_purpose,
-        persons_merged,
-        destination_sample,
-        model_settings,
-        network_los,
-        chunk_size,
-        trace_label):
+    tour_purpose,
+    persons_merged,
+    destination_sample,
+    model_settings,
+    network_los,
+    chunk_size,
+    trace_label,
+):
     """
     add logsum column to existing tour_destination_sample table
 
@@ -523,82 +611,103 @@ def run_destination_logsums(
     +-----------+--------------+----------------+------------+----------------+
     """
 
-    logsum_settings = config.read_model_settings(model_settings['LOGSUM_SETTINGS'])
+    logsum_settings = config.read_model_settings(model_settings["LOGSUM_SETTINGS"])
 
-    chunk_tag = 'tour_destination.logsums'
+    chunk_tag = "tour_destination.logsums"
 
     # FIXME - MEMORY HACK - only include columns actually used in spec
-    persons_merged = logsum.filter_chooser_columns(persons_merged, logsum_settings, model_settings)
+    persons_merged = logsum.filter_chooser_columns(
+        persons_merged, logsum_settings, model_settings
+    )
 
     # merge persons into tours
-    choosers = pd.merge(destination_sample,
-                        persons_merged,
-                        left_on='person_id',
-                        right_index=True,
-                        how="left")
+    choosers = pd.merge(
+        destination_sample,
+        persons_merged,
+        left_on="person_id",
+        right_index=True,
+        how="left",
+    )
 
     logger.info("Running %s with %s rows", trace_label, len(choosers))
 
-    tracing.dump_df(DUMP, persons_merged, trace_label, 'persons_merged')
-    tracing.dump_df(DUMP, choosers, trace_label, 'choosers')
+    tracing.dump_df(DUMP, persons_merged, trace_label, "persons_merged")
+    tracing.dump_df(DUMP, choosers, trace_label, "choosers")
 
     logsums = logsum.compute_logsums(
         choosers,
         tour_purpose,
-        logsum_settings, model_settings,
+        logsum_settings,
+        model_settings,
         network_los,
         chunk_size,
         chunk_tag,
-        trace_label)
+        trace_label,
+    )
 
-    destination_sample['mode_choice_logsum'] = logsums
+    destination_sample["mode_choice_logsum"] = logsums
 
     return destination_sample
 
 
 def run_destination_simulate(
-        spec_segment_name,
-        tours,
-        persons_merged,
-        destination_sample,
-        want_logsums,
-        model_settings,
-        network_los,
-        destination_size_terms,
-        estimator,
-        chunk_size, trace_label):
+    spec_segment_name,
+    tours,
+    persons_merged,
+    destination_sample,
+    want_logsums,
+    model_settings,
+    network_los,
+    destination_size_terms,
+    estimator,
+    chunk_size,
+    trace_label,
+):
     """
     run destination_simulate on tour_destination_sample
     annotated with mode_choice logsum to select a destination from sample alternatives
     """
-    chunk_tag = 'tour_destination.simulate'
+    chunk_tag = "tour_destination.simulate"
 
-    model_spec = simulate.spec_for_segment(model_settings, spec_id='SPEC',
-                                           segment_name=spec_segment_name, estimator=estimator)
+    model_spec = simulate.spec_for_segment(
+        model_settings,
+        spec_id="SPEC",
+        segment_name=spec_segment_name,
+        estimator=estimator,
+    )
 
     # FIXME - MEMORY HACK - only include columns actually used in spec (omit them pre-merge)
-    chooser_columns = model_settings['SIMULATE_CHOOSER_COLUMNS']
-    persons_merged = persons_merged[[c for c in persons_merged.columns if c in chooser_columns]]
-    tours = tours[[c for c in tours.columns if c in chooser_columns or c == 'person_id']]
-    choosers = pd.merge(tours, persons_merged, left_on='person_id', right_index=True, how='left')
+    chooser_columns = model_settings["SIMULATE_CHOOSER_COLUMNS"]
+    persons_merged = persons_merged[
+        [c for c in persons_merged.columns if c in chooser_columns]
+    ]
+    tours = tours[
+        [c for c in tours.columns if c in chooser_columns or c == "person_id"]
+    ]
+    choosers = pd.merge(
+        tours, persons_merged, left_on="person_id", right_index=True, how="left"
+    )
 
     # interaction_sample requires that choosers.index.is_monotonic_increasing
     if not choosers.index.is_monotonic_increasing:
-        logger.debug(f"run_destination_simulate {trace_label} sorting choosers because not monotonic_increasing")
+        logger.debug(
+            f"run_destination_simulate {trace_label} sorting choosers because not monotonic_increasing"
+        )
         choosers = choosers.sort_index()
 
     if estimator:
         estimator.write_choosers(choosers)
 
-    alt_dest_col_name = model_settings['ALT_DEST_COL_NAME']
-    origin_col_name = model_settings['CHOOSER_ORIG_COL_NAME']
+    alt_dest_col_name = model_settings["ALT_DEST_COL_NAME"]
+    origin_col_name = model_settings["CHOOSER_ORIG_COL_NAME"]
 
     # alternatives are pre-sampled and annotated with logsums and pick_count
     # but we have to merge size_terms column into alt sample list
-    destination_sample['size_term'] = \
-        reindex(destination_size_terms.size_term, destination_sample[alt_dest_col_name])
+    destination_sample["size_term"] = reindex(
+        destination_size_terms.size_term, destination_sample[alt_dest_col_name]
+    )
 
-    tracing.dump_df(DUMP, destination_sample, trace_label, 'alternatives')
+    tracing.dump_df(DUMP, destination_sample, trace_label, "alternatives")
 
     constants = config.get_model_constants(model_settings)
 
@@ -611,14 +720,14 @@ def run_destination_simulate(
     skims = skim_dict.wrap(origin_col_name, alt_dest_col_name)
 
     locals_d = {
-        'skims': skims,
+        "skims": skims,
     }
     if constants is not None:
         locals_d.update(constants)
 
-    tracing.dump_df(DUMP, choosers, trace_label, 'choosers')
+    tracing.dump_df(DUMP, choosers, trace_label, "choosers")
 
-    log_alt_losers = config.setting('log_alt_losers', False)
+    log_alt_losers = config.setting("log_alt_losers", False)
 
     choices = interaction_sample_simulate(
         choosers,
@@ -629,38 +738,44 @@ def run_destination_simulate(
         want_logsums=want_logsums,
         skims=skims,
         locals_d=locals_d,
-        chunk_size=chunk_size, chunk_tag=chunk_tag,
+        chunk_size=chunk_size,
+        chunk_tag=chunk_tag,
         trace_label=trace_label,
-        trace_choice_name='destination',
-        estimator=estimator)
+        trace_choice_name="destination",
+        estimator=estimator,
+    )
 
     if not want_logsums:
         # for consistency, always return a dataframe with canonical column name
         assert isinstance(choices, pd.Series)
-        choices = choices.to_frame('choice')
+        choices = choices.to_frame("choice")
 
     return choices
 
 
 def run_tour_destination(
-        tours,
-        persons_merged,
-        want_logsums,
-        want_sample_table,
-        model_settings,
-        network_los,
-        estimator,
-        chunk_size, trace_hh_id, trace_label):
+    tours,
+    persons_merged,
+    want_logsums,
+    want_sample_table,
+    model_settings,
+    network_los,
+    estimator,
+    chunk_size,
+    trace_hh_id,
+    trace_label,
+):
 
-    size_term_calculator = SizeTermCalculator(model_settings['SIZE_TERM_SELECTOR'])
+    size_term_calculator = SizeTermCalculator(model_settings["SIZE_TERM_SELECTOR"])
 
     # maps segment names to compact (integer) ids
-    segments = model_settings['SEGMENTS']
+    segments = model_settings["SEGMENTS"]
 
-    chooser_segment_column = model_settings.get('CHOOSER_SEGMENT_COLUMN_NAME', None)
+    chooser_segment_column = model_settings.get("CHOOSER_SEGMENT_COLUMN_NAME", None)
     if chooser_segment_column is None:
-        assert len(segments) == 1, \
-            f"CHOOSER_SEGMENT_COLUMN_NAME not specified in model_settings to slice SEGMENTS: {segments}"
+        assert (
+            len(segments) == 1
+        ), f"CHOOSER_SEGMENT_COLUMN_NAME not specified in model_settings to slice SEGMENTS: {segments}"
 
     choices_list = []
     sample_list = []
@@ -674,59 +789,65 @@ def run_tour_destination(
             choosers = tours.copy()
 
         # Note: size_term_calculator omits zones with impossible alternatives (where dest size term is zero)
-        segment_destination_size_terms = size_term_calculator.dest_size_terms_df(segment_name, segment_trace_label)
+        segment_destination_size_terms = size_term_calculator.dest_size_terms_df(
+            segment_name, segment_trace_label
+        )
 
         if choosers.shape[0] == 0:
-            logger.info("%s skipping segment %s: no choosers", trace_label, segment_name)
+            logger.info(
+                "%s skipping segment %s: no choosers", trace_label, segment_name
+            )
             continue
 
         # - destination_sample
         spec_segment_name = segment_name  # spec_segment_name is segment_name
-        location_sample_df = \
-            run_destination_sample(
-                spec_segment_name,
-                choosers,
-                persons_merged,
-                model_settings,
-                network_los,
-                segment_destination_size_terms,
-                estimator,
-                chunk_size=chunk_size,
-                trace_label=tracing.extend_trace_label(segment_trace_label, 'sample'))
+        location_sample_df = run_destination_sample(
+            spec_segment_name,
+            choosers,
+            persons_merged,
+            model_settings,
+            network_los,
+            segment_destination_size_terms,
+            estimator,
+            chunk_size=chunk_size,
+            trace_label=tracing.extend_trace_label(segment_trace_label, "sample"),
+        )
 
         # - destination_logsums
         tour_purpose = segment_name  # tour_purpose is segment_name
-        location_sample_df = \
-            run_destination_logsums(
-                tour_purpose,
-                persons_merged,
-                location_sample_df,
-                model_settings,
-                network_los,
-                chunk_size=chunk_size,
-                trace_label=tracing.extend_trace_label(segment_trace_label, 'logsums'))
+        location_sample_df = run_destination_logsums(
+            tour_purpose,
+            persons_merged,
+            location_sample_df,
+            model_settings,
+            network_los,
+            chunk_size=chunk_size,
+            trace_label=tracing.extend_trace_label(segment_trace_label, "logsums"),
+        )
 
         # - destination_simulate
         spec_segment_name = segment_name  # spec_segment_name is segment_name
-        choices = \
-            run_destination_simulate(
-                spec_segment_name,
-                choosers,
-                persons_merged,
-                destination_sample=location_sample_df,
-                want_logsums=want_logsums,
-                model_settings=model_settings,
-                network_los=network_los,
-                destination_size_terms=segment_destination_size_terms,
-                estimator=estimator,
-                chunk_size=chunk_size,
-                trace_label=tracing.extend_trace_label(segment_trace_label, 'simulate'))
+        choices = run_destination_simulate(
+            spec_segment_name,
+            choosers,
+            persons_merged,
+            destination_sample=location_sample_df,
+            want_logsums=want_logsums,
+            model_settings=model_settings,
+            network_los=network_los,
+            destination_size_terms=segment_destination_size_terms,
+            estimator=estimator,
+            chunk_size=chunk_size,
+            trace_label=tracing.extend_trace_label(segment_trace_label, "simulate"),
+        )
 
         choices_list.append(choices)
 
         if want_sample_table:
             # FIXME - sample_table
-            location_sample_df.set_index(model_settings['ALT_DEST_COL_NAME'], append=True, inplace=True)
+            location_sample_df.set_index(
+                model_settings["ALT_DEST_COL_NAME"], append=True, inplace=True
+            )
             sample_list.append(location_sample_df)
         else:
             # del this so we dont hold active reference to it while run_location_sample is creating its replacement
@@ -737,7 +858,7 @@ def run_tour_destination(
     else:
         # this will only happen with small samples (e.g. singleton) with no (e.g.) school segs
         logger.warning("%s no choices", trace_label)
-        choices_df = pd.DataFrame(columns=['choice', 'logsum'])
+        choices_df = pd.DataFrame(columns=["choice", "logsum"])
 
     if len(sample_list) > 0:
         save_sample_df = pd.concat(sample_list)
