@@ -1,11 +1,11 @@
 # ActivitySim
 # See full license in LICENSE.txt.
 import os
+
 import pytest
 
 from activitysim.core import inject
 
-
 # The following import statement has the side-effect of registering injectables:
 from .. import __init__
 
@@ -26,13 +26,13 @@ def test_misc():
         inject.get_injectable("output_dir")
     assert "directory does not exist" in str(excinfo.value)
 
-    configs_dir = os.path.join(os.path.dirname(__file__), 'configs_test_misc')
+    configs_dir = os.path.join(os.path.dirname(__file__), "configs_test_misc")
     inject.add_injectable("configs_dir", configs_dir)
 
     settings = inject.get_injectable("settings")
     assert isinstance(settings, dict)
 
-    data_dir = os.path.join(os.path.dirname(__file__), 'data')
+    data_dir = os.path.join(os.path.dirname(__file__), "data")
     inject.add_injectable("data_dir", data_dir)
 
     # default values if not specified in settings
