@@ -5,9 +5,17 @@ import pytest
 from activitysim.abm.models.util.trip import get_time_windows
 
 
-@pytest.mark.parametrize("duration, levels, expected",
-                         [(24, 3, 2925), (24, 2, 325), (24, 1, 25),
-                          (48, 3, 20825), (48, 2, 1225), (48, 1, 49)])
+@pytest.mark.parametrize(
+    "duration, levels, expected",
+    [
+        (24, 3, 2925),
+        (24, 2, 325),
+        (24, 1, 25),
+        (48, 3, 20825),
+        (48, 2, 1225),
+        (48, 1, 49),
+    ],
+)
 def test_get_time_windows(duration, levels, expected):
     time_windows = get_time_windows(duration, levels)
 
