@@ -11,37 +11,38 @@ _DECORATED_INJECTABLES = {}
 
 
 # we want to allow None (any anyting else) as a default value, so just choose an improbable string
-_NO_DEFAULT = 'throw error if missing'
+_NO_DEFAULT = "throw error if missing"
 
 logger = logging.getLogger(__name__)
 
 
 def step():
-
     def decorator(func):
         name = func.__name__
 
         logger.debug("inject step %s" % name)
 
-        assert not _DECORATED_STEPS.get(name, False), \
+        assert not _DECORATED_STEPS.get(name, False), (
             "step '%s' already decorated." % name
+        )
         _DECORATED_STEPS[name] = func
 
         orca.add_step(name, func)
 
         return func
+
     return decorator
 
 
 def table():
-
     def decorator(func):
         name = func.__name__
 
         logger.debug("inject table %s" % name)
 
-        assert not _DECORATED_TABLES.get(name, False), \
+        assert not _DECORATED_TABLES.get(name, False), (
             "table '%s' already decorated." % name
+        )
         _DECORATED_TABLES[name] = func
 
         orca.add_table(name, func)
@@ -58,14 +59,16 @@ def injectable(cache=False, override=False):
         logger.debug("inject injectable %s" % name)
 
         # insist on explicit override to ensure multiple definitions occur in correct order
-        assert override or not _DECORATED_INJECTABLES.get(name, False), \
+        assert override or not _DECORATED_INJECTABLES.get(name, False), (
             "injectable '%s' already defined. not overridden" % name
+        )
 
-        _DECORATED_INJECTABLES[name] = {'func': func, 'cache': cache}
+        _DECORATED_INJECTABLES[name] = {"func": func, "cache": cache}
 
         orca.add_injectable(name, func, cache=cache)
 
         return func
+
     return decorator
 
 
@@ -82,7 +85,11 @@ def add_table(table_name, table, replace=False):
     Add new table and raise assertion error if the table already exists.
     Silently replace if replace=True.
     """
-    if not replace and orca.is_table(table_name) and orca.table_type(table_name) == 'dataframe':
+    if (
+        not replace
+        and orca.is_table(table_name)
+        and orca.table_type(table_name) == "dataframe"
+    ):
         logger.warning("inject add_table replacing existing table %s" % table_name)
         assert False
 
@@ -99,10 +106,17 @@ def add_injectable(name, injectable, cache=False):
     return orca.add_injectable(name, injectable, cache=cache)
 
 
-def broadcast(cast, onto, cast_on=None, onto_on=None, cast_index=False, onto_index=False):
-    return orca.broadcast(cast, onto,
-                          cast_on=cast_on, onto_on=onto_on,
-                          cast_index=cast_index, onto_index=onto_index)
+def broadcast(
+    cast, onto, cast_on=None, onto_on=None, cast_index=False, onto_index=False
+):
+    return orca.broadcast(
+        cast,
+        onto,
+        cast_on=cast_on,
+        onto_on=onto_on,
+        cast_index=cast_index,
+        onto_index=onto_index,
+    )
 
 
 def get_table(name, default=_NO_DEFAULT):
@@ -151,11 +165,11 @@ def reinject_decorated_tables():
     for column_key, args in _DECORATED_COLUMNS.items():
         table_name, column_name = column_key
         logger.debug("reinject decorated column %s.%s" % (table_name, column_name))
-        orca.add_column(table_name, column_name, args['func'], cache=args['cache'])
+        orca.add_column(table_name, column_name, args["func"], cache=args["cache"])
 
     for name, args in _DECORATED_INJECTABLES.items():
         logger.debug("reinject decorated injectable %s" % name)
-        orca.add_injectable(name, args['func'], cache=args['cache'])
+        orca.add_injectable(name, args["func"], cache=args["cache"])
 
 
 def clear_cache():
@@ -165,12 +179,12 @@ def clear_cache():
 def set_step_args(args=None):
 
     assert isinstance(args, dict) or args is None
-    orca.add_injectable('step_args', args)
+    orca.add_injectable("step_args", args)
 
 
 def get_step_arg(arg_name, default=_NO_DEFAULT):
 
-    args = orca.get_injectable('step_args')
+    args = orca.get_injectable("step_args")
 
     assert isinstance(args, dict)
     if arg_name not in args and default == _NO_DEFAULT:
