@@ -1,24 +1,22 @@
 # ActivitySim
 # See full license in LICENSE.txt.
 
-from builtins import range
-from builtins import object
-
-import logging
 import hashlib
+import logging
+from builtins import object, range
 
 import numpy as np
 import pandas as pd
+
 from activitysim.core.util import reindex
 
 from .tracing import print_elapsed_time
 
-
 logger = logging.getLogger(__name__)
 
 # one more than 0xFFFFFFFF so we can wrap using: int64 % _MAX_SEED
-_MAX_SEED = (1 << 32)
-_SEED_MASK = 0xffffffff
+_MAX_SEED = 1 << 32
+_SEED_MASK = 0xFFFFFFFF
 
 
 def hash32(s):
@@ -32,7 +30,7 @@ def hash32(s):
     -------
         32 bit unsigned hash
     """
-    s = s.encode('utf8')
+    s = s.encode("utf8")
     h = hashlib.md5(s).hexdigest()
     return int(h, base=16) & _SEED_MASK
 
@@ -103,13 +101,12 @@ class SimpleChannel(object):
 
         if self.step_name and not row_states.empty:
 
-            row_states['row_seed'] = (self.base_seed +
-                                      self.channel_seed +
-                                      self.step_seed +
-                                      row_states.index) % _MAX_SEED
+            row_states["row_seed"] = (
+                self.base_seed + self.channel_seed + self.step_seed + row_states.index
+            ) % _MAX_SEED
 
             # number of rands pulled this step
-            row_states['offset'] = 0
+            row_states["offset"] = 0
 
         return row_states
 
@@ -128,10 +125,12 @@ class SimpleChannel(object):
         """
 
         if domain_df.empty:
-            logger.warning("extend_domain for channel %s for empty domain_df" % self.channel_name)
+            logger.warning(
+                "extend_domain for channel %s for empty domain_df" % self.channel_name
+            )
 
         # dataframe to hold state for every df row
-        row_states = pd.DataFrame(columns=['row_seed', 'offset'], index=domain_df.index)
+        row_states = pd.DataFrame(columns=["row_seed", "offset"], index=domain_df.index)
 
         if self.step_name and not row_states.empty:
             self.init_row_states_for_step(row_states)
@@ -170,8 +169,8 @@ class SimpleChannel(object):
 
         self.step_name = None
         self.step_seed = None
-        self.row_states['offset'] = 0
-        self.row_states['row_seed'] = 0
+        self.row_states["offset"] = 0
+        self.row_states["row_seed"] = 0
 
     def _generators_for_df(self, df):
         """
@@ -245,7 +244,7 @@ class SimpleChannel(object):
 
         rands = np.asanyarray([prng.rand(n) for prng in generators])
         # update offset for rows we handled
-        self.row_states.loc[df.index, 'offset'] += n
+        self.row_states.loc[df.index, "offset"] += n
         return rands
 
     def normal_for_df(self, df, step_name, mu, sigma, lognormal=False):
@@ -295,16 +294,22 @@ class SimpleChannel(object):
         sigma = to_series(sigma)
 
         if lognormal:
-            rands = \
-                np.asanyarray([prng.lognormal(mean=mu[i], sigma=sigma[i])
-                               for i, prng in enumerate(generators)])
+            rands = np.asanyarray(
+                [
+                    prng.lognormal(mean=mu[i], sigma=sigma[i])
+                    for i, prng in enumerate(generators)
+                ]
+            )
         else:
-            rands = \
-                np.asanyarray([prng.normal(loc=mu[i], scale=sigma[i])
-                               for i, prng in enumerate(generators)])
+            rands = np.asanyarray(
+                [
+                    prng.normal(loc=mu[i], scale=sigma[i])
+                    for i, prng in enumerate(generators)
+                ]
+            )
 
         # update offset for rows we handled
-        self.row_states.loc[df.index, 'offset'] += 1
+        self.row_states.loc[df.index, "offset"] += 1
 
         return rands
 
@@ -350,20 +355,21 @@ class SimpleChannel(object):
         # initialize the generator iterator
         generators = self._generators_for_df(df)
 
-        sample = np.concatenate(tuple(prng.choice(a, size, replace) for prng in generators))
+        sample = np.concatenate(
+            tuple(prng.choice(a, size, replace) for prng in generators)
+        )
 
         if not self.multi_choice_offset:
             # FIXME - if replace, should we estimate rands_consumed?
             if replace:
                 logger.warning("choice_for_df MULTI_CHOICE_FF with replace")
             # update offset for rows we handled
-            self.row_states.loc[df.index, 'offset'] += size
+            self.row_states.loc[df.index, "offset"] += size
 
         return sample
 
 
 class Random(object):
-
     def __init__(self):
 
         self.channels = {}
@@ -462,20 +468,22 @@ class Random(object):
         if channel_name in self.channels:
 
             assert channel_name == self.index_to_channel[domain_df.index.name]
-            logger.debug("Random: extending channel '%s' %s ids" %
-                         (channel_name, len(domain_df.index)))
+            logger.debug(
+                "Random: extending channel '%s' %s ids"
+                % (channel_name, len(domain_df.index))
+            )
             channel = self.channels[channel_name]
 
             channel.extend_domain(domain_df)
 
         else:
-            logger.debug("Adding channel '%s' %s ids" % (channel_name, len(domain_df.index)))
+            logger.debug(
+                "Adding channel '%s' %s ids" % (channel_name, len(domain_df.index))
+            )
 
-            channel = SimpleChannel(channel_name,
-                                    self.base_seed,
-                                    domain_df,
-                                    self.step_name
-                                    )
+            channel = SimpleChannel(
+                channel_name, self.base_seed, domain_df, self.step_name
+            )
 
             self.channels[channel_name] = channel
             self.index_to_channel[domain_df.index.name] = channel_name
@@ -490,10 +498,12 @@ class Random(object):
         """
 
         if channel_name in self.channels:
-            logger.debug("Dropping channel '%s'" % (channel_name, ))
+            logger.debug("Dropping channel '%s'" % (channel_name,))
             del self.channels[channel_name]
         else:
-            logger.error("drop_channel called with unknown channel '%s'" % (channel_name,))
+            logger.error(
+                "drop_channel called with unknown channel '%s'" % (channel_name,)
+            )
 
     def set_base_seed(self, seed=None):
         """
@@ -640,11 +650,15 @@ class Random(object):
         if broadcast:
             alts_df = df
             df = df.index.unique().to_series()
-            rands = channel.normal_for_df(df, self.step_name, mu=0, sigma=1, lognormal=False)
+            rands = channel.normal_for_df(
+                df, self.step_name, mu=0, sigma=1, lognormal=False
+            )
             rands = reindex(pd.Series(rands, index=df.index), alts_df.index)
-            rands = rands*sigma + mu
+            rands = rands * sigma + mu
         else:
-            rands = channel.normal_for_df(df, self.step_name, mu, sigma, lognormal=False)
+            rands = channel.normal_for_df(
+                df, self.step_name, mu, sigma, lognormal=False
+            )
 
         return rands
 
@@ -703,7 +717,9 @@ class Random(object):
             rands = np.exp(rands)
         else:
             channel = self.get_channel_for_df(df)
-            rands = channel.normal_for_df(df, self.step_name, mu=mu, sigma=sigma, lognormal=True)
+            rands = channel.normal_for_df(
+                df, self.step_name, mu=mu, sigma=sigma, lognormal=True
+            )
 
         return rands
 
@@ -746,11 +762,15 @@ class Random(object):
         # FIXME - for tests
         if not self.channels:
             rng = np.random.RandomState(0)
-            choices = np.concatenate(tuple(rng.choice(a, size, replace) for _ in range(len(df))))
+            choices = np.concatenate(
+                tuple(rng.choice(a, size, replace) for _ in range(len(df)))
+            )
             return choices
 
         t0 = print_elapsed_time()
         channel = self.get_channel_for_df(df)
         choices = channel.choice_for_df(df, self.step_name, a, size, replace)
-        t0 = print_elapsed_time("choice_for_df for %s rows" % len(df.index), t0, debug=True)
+        t0 = print_elapsed_time(
+            "choice_for_df for %s rows" % len(df.index), t0, debug=True
+        )
         return choices
