@@ -4,10 +4,8 @@ import os
 
 import pytest
 
-from .. import inject
-
 # Note that the following import statement has the side-effect of registering injectables:
-from .. import config
+from .. import config, inject
 
 
 def teardown_function(func):
@@ -32,11 +30,11 @@ def test_defaults():
         print("output_dir", output_dir)
     assert "directory does not exist" in str(excinfo.value)
 
-    configs_dir = os.path.join(os.path.dirname(__file__), 'configs_test_defaults')
+    configs_dir = os.path.join(os.path.dirname(__file__), "configs_test_defaults")
     inject.add_injectable("configs_dir", configs_dir)
 
     settings = inject.get_injectable("settings")
     assert isinstance(settings, dict)
 
-    data_dir = os.path.join(os.path.dirname(__file__), 'data')
+    data_dir = os.path.join(os.path.dirname(__file__), "data")
     inject.add_injectable("data_dir", data_dir)
