@@ -1,16 +1,13 @@
 # ActivitySim
 # See full license in LICENSE.txt.
 
-from builtins import range
-from builtins import object
-
 import logging
+from builtins import object, range
 
 import numpy as np
 import pandas as pd
 
-from activitysim.core import pipeline
-from activitysim.core import chunk
+from activitysim.core import chunk, pipeline
 
 logger = logging.getLogger(__name__)
 
@@ -31,9 +28,12 @@ COLLISIONS = [
     [I_START, I_START],
     [I_END, I_END],
     [I_MIDDLE, I_MIDDLE],
-    [I_START, I_MIDDLE], [I_MIDDLE, I_START],
-    [I_END, I_MIDDLE], [I_MIDDLE, I_END],
-    [I_START_END, I_MIDDLE], [I_MIDDLE, I_START_END],
+    [I_START, I_MIDDLE],
+    [I_MIDDLE, I_START],
+    [I_END, I_MIDDLE],
+    [I_MIDDLE, I_END],
+    [I_START_END, I_MIDDLE],
+    [I_MIDDLE, I_START_END],
 ]
 
 COLLISION_LIST = [a + (b << I_BIT_SHIFT) for a, b in COLLISIONS]
@@ -47,25 +47,25 @@ C_MIDDLE = str(I_MIDDLE)
 C_START_END = str(I_START_END)
 
 
-def tour_map(persons, tours, tdd_alts, persons_id_col='person_id'):
+def tour_map(persons, tours, tdd_alts, persons_id_col="person_id"):
 
     sigil = {
-        'empty': '   ',
-        'overlap': '+++',
-        'work': 'WWW',
-        'school': 'SSS',
-        'escort': 'esc',
-        'shopping': 'shp',
-        'othmaint': 'mnt',
-        'othdiscr': 'dsc',
-        'eatout': 'eat',
-        'social': 'soc',
-        'eat': 'eat',
-        'business': 'bus',
-        'maint': 'mnt'
+        "empty": "   ",
+        "overlap": "+++",
+        "work": "WWW",
+        "school": "SSS",
+        "escort": "esc",
+        "shopping": "shp",
+        "othmaint": "mnt",
+        "othdiscr": "dsc",
+        "eatout": "eat",
+        "social": "soc",
+        "eat": "eat",
+        "business": "bus",
+        "maint": "mnt",
     }
 
-    sigil_type = 'S3'
+    sigil_type = "S3"
 
     # we can only map scheduled tours
     tours = tours[tours.tdd.notnull()]
@@ -76,7 +76,7 @@ def tour_map(persons, tours, tdd_alts, persons_id_col='person_id'):
     n_periods = max_period - min_period + 1
     n_persons = len(persons.index)
 
-    agenda = np.array([sigil['empty']]*(n_periods*n_persons), dtype=sigil_type)
+    agenda = np.array([sigil["empty"]] * (n_periods * n_persons), dtype=sigil_type)
     agenda = agenda.reshape(n_persons, n_periods)
 
     scheduled = np.zeros_like(agenda, dtype=int)
@@ -84,15 +84,16 @@ def tour_map(persons, tours, tdd_alts, persons_id_col='person_id'):
 
     # construct with strings so we can create runs of strings using char * int
     w_strings = [
-        '0' * (row.start - min_period) +
-        '1' * (row.duration + 1) +
-        '0' * (max_period - row.end)
-        for idx, row in tdd_alts.iterrows()]
+        "0" * (row.start - min_period)
+        + "1" * (row.duration + 1)
+        + "0" * (max_period - row.end)
+        for idx, row in tdd_alts.iterrows()
+    ]
 
     window_periods = np.asanyarray([list(r) for r in w_strings]).astype(int)
     window_periods_df = pd.DataFrame(data=window_periods, index=tdd_alts.index)
 
-    for keys, nth_tours in tours.groupby(['tour_type', 'tour_type_num'], sort=True):
+    for keys, nth_tours in tours.groupby(["tour_type", "tour_type_num"], sort=True):
 
         tour_type = keys[0]
         tour_sigil = sigil[tour_type]
@@ -110,10 +111,12 @@ def tour_map(persons, tours, tdd_alts, persons_id_col='person_id'):
         agenda[row_ixs] = np.where(tour_windows, tour_sigil, agenda[row_ixs])
 
     # show tour overlaps
-    agenda = np.where(scheduled > 1, sigil['overlap'], agenda)
+    agenda = np.where(scheduled > 1, sigil["overlap"], agenda)
 
     # a = pd.Series([' '.join(a) for a in agenda], index=persons.index)
-    a = pd.DataFrame(data=agenda, columns=[str(w) for w in range(min_period, max_period+1)])
+    a = pd.DataFrame(
+        data=agenda, columns=[str(w) for w in range(min_period, max_period + 1)]
+    )
 
     a.index = persons.index
     a.index.name = persons_id_col
@@ -157,10 +160,9 @@ def create_timetable_windows(rows, tdd_alts):
 
     UNSCHEDULED = 0
 
-    df = pd.DataFrame(data=UNSCHEDULED,
-                      index=rows.index,
-                      columns=window_cols,
-                      dtype=np.int8)
+    df = pd.DataFrame(
+        data=UNSCHEDULED, index=rows.index, columns=window_cols, dtype=np.int8
+    )
 
     return df
 
@@ -194,21 +196,26 @@ class TimeTable(object):
         self.checkpoint_df = None
 
         # series to map window row index value to window row's ordinal index
-        self.window_row_ix = pd.Series(list(range(len(windows_df.index))), index=windows_df.index)
+        self.window_row_ix = pd.Series(
+            list(range(len(windows_df.index))), index=windows_df.index
+        )
 
         int_time_periods = [int(c) for c in windows_df.columns.values]
-        self.time_ix = pd.Series(list(range(len(windows_df.columns))), index=int_time_periods)
+        self.time_ix = pd.Series(
+            list(range(len(windows_df.columns))), index=int_time_periods
+        )
 
         # - pre-compute window state footprints for every tdd_alt
         min_period = min(int_time_periods)
         max_period = max(int_time_periods)
         # construct with strings so we can create runs of strings using char * int
         w_strings = [
-            C_EMPTY * (row.start - min_period) +
-            (C_START + C_MIDDLE * (row.duration - 1) if row.duration > 0 else '') +
-            (C_END if row.duration > 0 else C_START_END) +
-            (C_EMPTY * (max_period - row.end))
-            for idx, row in tdd_alts_df.iterrows()]
+            C_EMPTY * (row.start - min_period)
+            + (C_START + C_MIDDLE * (row.duration - 1) if row.duration > 0 else "")
+            + (C_END if row.duration > 0 else C_START_END)
+            + (C_EMPTY * (max_period - row.end))
+            for idx, row in tdd_alts_df.iterrows()
+        ]
 
         # we want range index so we can use raw numpy
         assert (tdd_alts_df.index == list(range(tdd_alts_df.shape[0]))).all()
@@ -223,7 +230,9 @@ class TimeTable(object):
         if not isinstance(transaction_loggers, list):
             transaction_loggers = [transaction_loggers]
         for transaction_logger in transaction_loggers:
-            transaction_logger.log("timetable.begin_transaction %s" % self.windows_table_name)
+            transaction_logger.log(
+                "timetable.begin_transaction %s" % self.windows_table_name
+            )
         self.checkpoint_df = self.windows_df.copy()
         self.transaction_loggers = transaction_loggers
         pass
@@ -281,8 +290,11 @@ class TimeTable(object):
         assert self.windows_table_name is not None
         if self.checkpoint_df is not None:
             for logger in self.transaction_loggers.values():
-                logger.log("Attempt to replace_table while in transaction: %s" %
-                           self.windows_table_name, level=logging.ERROR)
+                logger.log(
+                    "Attempt to replace_table while in transaction: %s"
+                    % self.windows_table_name,
+                    level=logging.ERROR,
+                )
             raise RuntimeError("Attempt to replace_table while in transaction")
 
         # get windows_df from bottleneck function in case updates to self.person_window
@@ -421,7 +433,7 @@ class TimeTable(object):
         available1 = (self.slice_windows_by_row_id(window1_row_ids) != I_MIDDLE) * 1
         available2 = (self.slice_windows_by_row_id(window2_row_ids) != I_MIDDLE) * 1
 
-        return (available1 * available2)
+        return available1 * available2
 
     def individually_available(self, window_row_ids):
 
@@ -445,15 +457,15 @@ class TimeTable(object):
         """
         assert len(window_row_ids) == len(periods)
 
-        trace_label = 'tt.adjacent_window_run_length'
+        trace_label = "tt.adjacent_window_run_length"
         with chunk.chunk_log(trace_label):
 
             time_col_ixs = periods.map(self.time_ix).values
-            chunk.log_df(trace_label, 'time_col_ixs', time_col_ixs)
+            chunk.log_df(trace_label, "time_col_ixs", time_col_ixs)
 
             # sliced windows with 1s where windows state is I_MIDDLE and 0s elsewhere
             available = (self.slice_windows_by_row_id(window_row_ids) != I_MIDDLE) * 1
-            chunk.log_df(trace_label, 'available', available)
+            chunk.log_df(trace_label, "available", available)
 
             # padding periods not available
             available[:, 0] = 0
@@ -461,28 +473,34 @@ class TimeTable(object):
 
             # column idxs of windows
             num_rows, num_cols = available.shape
-            time_col_ix_map = np.tile(np.arange(0, num_cols), num_rows).reshape(num_rows, num_cols)
+            time_col_ix_map = np.tile(np.arange(0, num_cols), num_rows).reshape(
+                num_rows, num_cols
+            )
             # 0 1 2 3 4 5...
             # 0 1 2 3 4 5...
             # 0 1 2 3 4 5...
-            chunk.log_df(trace_label, 'time_col_ix_map', time_col_ix_map)
+            chunk.log_df(trace_label, "time_col_ix_map", time_col_ix_map)
 
             if before:
                 # ones after specified time, zeroes before
                 mask = (time_col_ix_map < time_col_ixs.reshape(num_rows, 1)) * 1
                 # index of first unavailable window after time
-                first_unavailable = np.where((1-available)*mask, time_col_ix_map, 0).max(axis=1)
+                first_unavailable = np.where(
+                    (1 - available) * mask, time_col_ix_map, 0
+                ).max(axis=1)
                 available_run_length = time_col_ixs - first_unavailable - 1
             else:
                 # ones after specified time, zeroes before
                 mask = (time_col_ix_map > time_col_ixs.reshape(num_rows, 1)) * 1
                 # index of first unavailable window after time
-                first_unavailable = np.where((1 - available) * mask, time_col_ix_map, num_cols).min(axis=1)
+                first_unavailable = np.where(
+                    (1 - available) * mask, time_col_ix_map, num_cols
+                ).min(axis=1)
                 available_run_length = first_unavailable - time_col_ixs - 1
 
-            chunk.log_df(trace_label, 'mask', mask)
-            chunk.log_df(trace_label, 'first_unavailable', first_unavailable)
-            chunk.log_df(trace_label, 'available_run_length', available_run_length)
+            chunk.log_df(trace_label, "mask", mask)
+            chunk.log_df(trace_label, "first_unavailable", first_unavailable)
+            chunk.log_df(trace_label, "available_run_length", available_run_length)
 
         return pd.Series(available_run_length, index=window_row_ids.index)
 
@@ -575,7 +593,9 @@ class TimeTable(object):
         pandas Series boolean
             indexed by window_row_ids.index
         """
-        return self.window_periods_in_states(window_row_ids, periods, [I_END, I_START_END])
+        return self.window_periods_in_states(
+            window_row_ids, periods, [I_END, I_START_END]
+        )
 
     def previous_tour_begins(self, window_row_ids, periods):
         """
@@ -596,7 +616,9 @@ class TimeTable(object):
             indexed by window_row_ids.index
         """
 
-        return self.window_periods_in_states(window_row_ids, periods, [I_START, I_START_END])
+        return self.window_periods_in_states(
+            window_row_ids, periods, [I_START, I_START_END]
+        )
 
     def remaining_periods_available(self, window_row_ids, starts, ends):
         """
@@ -627,7 +649,9 @@ class TimeTable(object):
         assert len(window_row_ids) == len(starts)
         assert len(window_row_ids) == len(ends)
 
-        available = (self.slice_windows_by_row_id(window_row_ids) != I_MIDDLE).sum(axis=1)
+        available = (self.slice_windows_by_row_id(window_row_ids) != I_MIDDLE).sum(
+            axis=1
+        )
 
         # don't count time window padding at both ends of day
         available -= 2
@@ -663,15 +687,21 @@ class TimeTable(object):
         available[:, 0] = 0
         available[:, -1] = 0
 
-        diffs = np.diff(available)  # 1 at start of run of availables, -1 at end, 0 everywhere else
-        start_row_index, starts = np.asarray(diffs > 0).nonzero()  # indices of run starts
+        diffs = np.diff(
+            available
+        )  # 1 at start of run of availables, -1 at end, 0 everywhere else
+        start_row_index, starts = np.asarray(
+            diffs > 0
+        ).nonzero()  # indices of run starts
         end_row_index, ends = np.asarray(diffs < 0).nonzero()  # indices of run ends
-        assert (start_row_index == end_row_index).all()  # because bounded, expect same number of starts and ends
+        assert (
+            start_row_index == end_row_index
+        ).all()  # because bounded, expect same number of starts and ends
 
         # run_lengths like availability but with run length at start of every run and zeros elsewhere
         # (row_indices of starts and ends are aligned, so end - start is run_length)
         run_lengths = np.zeros_like(available)
-        run_lengths[start_row_index, starts] = (ends - starts)
+        run_lengths[start_row_index, starts] = ends - starts
 
         # we just want to know the the longest one for each window_row_id
         max_run_lengths = run_lengths.max(axis=1)
